from context import *

from hybridfactory.io import spikegl


class TestGetStartTimeSingleFile:
    def setup(self):
        self.filename = op.join(testbase, "io", "anm420712_20180802_ch0-119bank1_ch120-382bank0_g0_t2.imec.ap.meta")

    def test_start_time(self):
        fn = self.filename
        assert((spikegl.get_start_times(fn) == np.zeros(1,)).all())

    def test_no_such_file(self):
        with pytest.raises(IOError):
            spikegl.get_start_times(op.join(testbase, "io", "not-a-file.meta"))

class TestGetStartTimesGlob:
    def setup(self):
        self.fileglob = op.join(testbase, "io", "anm365938_g0_t*.nidq.meta")
        with open(op.join(testbase, "io", "times.txt"), "r") as fh:
            times = np.array([int(l.strip()) for l in fh.readlines()])
        self.times = times - times[0]

    def test_start_times(self):
        fg = self.fileglob
        assert((spikegl.get_start_times(fg) == self.times).all())

    def test_no_start_times(self):
        with pytest.raises(IOError):
            spikegl.get_start_times(op.join(testbase, "io", "times.txt"))

class TestGetStartTimesList:
    def setup(self):
        self.filenames = [op.join(testbase, "io", fn) for fn in ["anm365938_g0_t0.nidq.meta", "anm365938_g0_t1.nidq.meta", "anm365938_g0_t2.nidq.meta", "anm365938_g0_t3.nidq.meta", "anm365938_g0_t4.nidq.meta", "anm365938_g0_t5.nidq.meta", "anm365938_g0_t6.nidq.meta", "anm365938_g0_t7.nidq.meta", "anm365938_g0_t8.nidq.meta", "anm365938_g0_t9.nidq.meta",
                                                                 "anm365938_g0_t10.nidq.meta", "anm365938_g0_t11.nidq.meta", "anm365938_g0_t12.nidq.meta", "anm365938_g0_t13.nidq.meta", "anm365938_g0_t14.nidq.meta", "anm365938_g0_t15.nidq.meta", "anm365938_g0_t16.nidq.meta", "anm365938_g0_t17.nidq.meta", "anm365938_g0_t18.nidq.meta", "anm365938_g0_t19.nidq.meta",
                                                                 "anm365938_g0_t20.nidq.meta", "anm365938_g0_t21.nidq.meta", "anm365938_g0_t22.nidq.meta", "anm365938_g0_t23.nidq.meta", "anm365938_g0_t24.nidq.meta", "anm365938_g0_t25.nidq.meta", "anm365938_g0_t26.nidq.meta", "anm365938_g0_t27.nidq.meta", "anm365938_g0_t28.nidq.meta", "anm365938_g0_t29.nidq.meta",
                                                                 "anm365938_g0_t30.nidq.meta", "anm365938_g0_t31.nidq.meta", "anm365938_g0_t32.nidq.meta", "anm365938_g0_t33.nidq.meta", "anm365938_g0_t34.nidq.meta", "anm365938_g0_t35.nidq.meta", "anm365938_g0_t36.nidq.meta", "anm365938_g0_t37.nidq.meta", "anm365938_g0_t38.nidq.meta", "anm365938_g0_t39.nidq.meta",
                                                                 "anm365938_g0_t40.nidq.meta", "anm365938_g0_t41.nidq.meta", "anm365938_g0_t42.nidq.meta", "anm365938_g0_t43.nidq.meta", "anm365938_g0_t44.nidq.meta", "anm365938_g0_t45.nidq.meta", "anm365938_g0_t46.nidq.meta", "anm365938_g0_t47.nidq.meta", "anm365938_g0_t48.nidq.meta", "anm365938_g0_t49.nidq.meta",
                                                                 "anm365938_g0_t50.nidq.meta", "anm365938_g0_t51.nidq.meta", "anm365938_g0_t52.nidq.meta", "anm365938_g0_t53.nidq.meta", "anm365938_g0_t54.nidq.meta", "anm365938_g0_t55.nidq.meta", "anm365938_g0_t56.nidq.meta", "anm365938_g0_t57.nidq.meta", "anm365938_g0_t58.nidq.meta", "anm365938_g0_t59.nidq.meta",
                                                                 "anm365938_g0_t60.nidq.meta", "anm365938_g0_t61.nidq.meta", "anm365938_g0_t62.nidq.meta", "anm365938_g0_t63.nidq.meta", "anm365938_g0_t64.nidq.meta", "anm365938_g0_t65.nidq.meta", "anm365938_g0_t66.nidq.meta", "anm365938_g0_t67.nidq.meta", "anm365938_g0_t68.nidq.meta", "anm365938_g0_t69.nidq.meta",
                                                                 "anm365938_g0_t70.nidq.meta", "anm365938_g0_t71.nidq.meta", "anm365938_g0_t72.nidq.meta", "anm365938_g0_t73.nidq.meta", "anm365938_g0_t74.nidq.meta", "anm365938_g0_t75.nidq.meta", "anm365938_g0_t76.nidq.meta", "anm365938_g0_t77.nidq.meta", "anm365938_g0_t78.nidq.meta", "anm365938_g0_t79.nidq.meta",
                                                                 "anm365938_g0_t80.nidq.meta", "anm365938_g0_t81.nidq.meta", "anm365938_g0_t82.nidq.meta", "anm365938_g0_t83.nidq.meta", "anm365938_g0_t84.nidq.meta", "anm365938_g0_t85.nidq.meta", "anm365938_g0_t86.nidq.meta", "anm365938_g0_t87.nidq.meta", "anm365938_g0_t88.nidq.meta", "anm365938_g0_t89.nidq.meta",
                                                                 "anm365938_g0_t90.nidq.meta", "anm365938_g0_t91.nidq.meta", "anm365938_g0_t92.nidq.meta", "anm365938_g0_t93.nidq.meta", "anm365938_g0_t94.nidq.meta", "anm365938_g0_t95.nidq.meta", "anm365938_g0_t96.nidq.meta", "anm365938_g0_t97.nidq.meta", "anm365938_g0_t98.nidq.meta", "anm365938_g0_t99.nidq.meta",
                                                                 "anm365938_g0_t100.nidq.meta", "anm365938_g0_t101.nidq.meta", "anm365938_g0_t102.nidq.meta", "anm365938_g0_t103.nidq.meta", "anm365938_g0_t104.nidq.meta", "anm365938_g0_t105.nidq.meta", "anm365938_g0_t106.nidq.meta", "anm365938_g0_t107.nidq.meta", "anm365938_g0_t108.nidq.meta", "anm365938_g0_t109.nidq.meta",
                                                                 "anm365938_g0_t110.nidq.meta", "anm365938_g0_t111.nidq.meta", "anm365938_g0_t112.nidq.meta", "anm365938_g0_t113.nidq.meta", "anm365938_g0_t114.nidq.meta", "anm365938_g0_t115.nidq.meta", "anm365938_g0_t116.nidq.meta", "anm365938_g0_t117.nidq.meta", "anm365938_g0_t118.nidq.meta", "anm365938_g0_t119.nidq.meta",
                                                                 "anm365938_g0_t120.nidq.meta", "anm365938_g0_t121.nidq.meta", "anm365938_g0_t122.nidq.meta", "anm365938_g0_t123.nidq.meta", "anm365938_g0_t124.nidq.meta", "anm365938_g0_t125.nidq.meta", "anm365938_g0_t126.nidq.meta", "anm365938_g0_t127.nidq.meta", "anm365938_g0_t128.nidq.meta", "anm365938_g0_t129.nidq.meta",
                                                                 "anm365938_g0_t130.nidq.meta", "anm365938_g0_t131.nidq.meta", "anm365938_g0_t132.nidq.meta", "anm365938_g0_t133.nidq.meta", "anm365938_g0_t134.nidq.meta", "anm365938_g0_t135.nidq.meta", "anm365938_g0_t136.nidq.meta", "anm365938_g0_t137.nidq.meta", "anm365938_g0_t138.nidq.meta", "anm365938_g0_t139.nidq.meta",
                                                                 "anm365938_g0_t140.nidq.meta", "anm365938_g0_t141.nidq.meta", "anm365938_g0_t142.nidq.meta", "anm365938_g0_t143.nidq.meta", "anm365938_g0_t144.nidq.meta", "anm365938_g0_t145.nidq.meta", "anm365938_g0_t146.nidq.meta", "anm365938_g0_t147.nidq.meta", "anm365938_g0_t148.nidq.meta", "anm365938_g0_t149.nidq.meta",
                                                                 "anm365938_g0_t150.nidq.meta", "anm365938_g0_t151.nidq.meta", "anm365938_g0_t152.nidq.meta", "anm365938_g0_t153.nidq.meta", "anm365938_g0_t154.nidq.meta", "anm365938_g0_t155.nidq.meta", "anm365938_g0_t156.nidq.meta", "anm365938_g0_t157.nidq.meta", "anm365938_g0_t158.nidq.meta", "anm365938_g0_t159.nidq.meta",
                                                                 "anm365938_g0_t160.nidq.meta", "anm365938_g0_t161.nidq.meta", "anm365938_g0_t162.nidq.meta", "anm365938_g0_t163.nidq.meta", "anm365938_g0_t164.nidq.meta", "anm365938_g0_t165.nidq.meta", "anm365938_g0_t166.nidq.meta", "anm365938_g0_t167.nidq.meta", "anm365938_g0_t168.nidq.meta", "anm365938_g0_t169.nidq.meta",
                                                                 "anm365938_g0_t170.nidq.meta", "anm365938_g0_t171.nidq.meta", "anm365938_g0_t172.nidq.meta", "anm365938_g0_t173.nidq.meta", "anm365938_g0_t174.nidq.meta", "anm365938_g0_t175.nidq.meta", "anm365938_g0_t176.nidq.meta", "anm365938_g0_t177.nidq.meta", "anm365938_g0_t178.nidq.meta", "anm365938_g0_t179.nidq.meta",
                                                                 "anm365938_g0_t180.nidq.meta", "anm365938_g0_t181.nidq.meta", "anm365938_g0_t182.nidq.meta", "anm365938_g0_t183.nidq.meta", "anm365938_g0_t184.nidq.meta", "anm365938_g0_t185.nidq.meta", "anm365938_g0_t186.nidq.meta", "anm365938_g0_t187.nidq.meta", "anm365938_g0_t188.nidq.meta", "anm365938_g0_t189.nidq.meta",
                                                                 "anm365938_g0_t190.nidq.meta", "anm365938_g0_t191.nidq.meta", "anm365938_g0_t192.nidq.meta", "anm365938_g0_t193.nidq.meta", "anm365938_g0_t194.nidq.meta", "anm365938_g0_t195.nidq.meta", "anm365938_g0_t196.nidq.meta", "anm365938_g0_t197.nidq.meta", "anm365938_g0_t198.nidq.meta", "anm365938_g0_t199.nidq.meta",
                                                                 "anm365938_g0_t200.nidq.meta", "anm365938_g0_t201.nidq.meta", "anm365938_g0_t202.nidq.meta", "anm365938_g0_t203.nidq.meta", "anm365938_g0_t204.nidq.meta", "anm365938_g0_t205.nidq.meta", "anm365938_g0_t206.nidq.meta", "anm365938_g0_t207.nidq.meta", "anm365938_g0_t208.nidq.meta", "anm365938_g0_t209.nidq.meta",
                                                                 "anm365938_g0_t210.nidq.meta", "anm365938_g0_t211.nidq.meta", "anm365938_g0_t212.nidq.meta", "anm365938_g0_t213.nidq.meta", "anm365938_g0_t214.nidq.meta", "anm365938_g0_t215.nidq.meta", "anm365938_g0_t216.nidq.meta", "anm365938_g0_t217.nidq.meta", "anm365938_g0_t218.nidq.meta", "anm365938_g0_t219.nidq.meta",
                                                                 "anm365938_g0_t220.nidq.meta", "anm365938_g0_t221.nidq.meta", "anm365938_g0_t222.nidq.meta", "anm365938_g0_t223.nidq.meta", "anm365938_g0_t224.nidq.meta", "anm365938_g0_t225.nidq.meta", "anm365938_g0_t226.nidq.meta", "anm365938_g0_t227.nidq.meta", "anm365938_g0_t228.nidq.meta", "anm365938_g0_t229.nidq.meta",
                                                                 "anm365938_g0_t230.nidq.meta", "anm365938_g0_t231.nidq.meta", "anm365938_g0_t232.nidq.meta", "anm365938_g0_t233.nidq.meta", "anm365938_g0_t234.nidq.meta", "anm365938_g0_t235.nidq.meta", "anm365938_g0_t236.nidq.meta", "anm365938_g0_t237.nidq.meta", "anm365938_g0_t238.nidq.meta", "anm365938_g0_t239.nidq.meta",
                                                                 "anm365938_g0_t240.nidq.meta", "anm365938_g0_t241.nidq.meta", "anm365938_g0_t242.nidq.meta", "anm365938_g0_t243.nidq.meta", "anm365938_g0_t244.nidq.meta", "anm365938_g0_t245.nidq.meta", "anm365938_g0_t246.nidq.meta", "anm365938_g0_t247.nidq.meta", "anm365938_g0_t248.nidq.meta", "anm365938_g0_t249.nidq.meta",
                                                                 "anm365938_g0_t250.nidq.meta", "anm365938_g0_t251.nidq.meta", "anm365938_g0_t252.nidq.meta", "anm365938_g0_t253.nidq.meta", "anm365938_g0_t254.nidq.meta", "anm365938_g0_t255.nidq.meta", "anm365938_g0_t256.nidq.meta", "anm365938_g0_t257.nidq.meta", "anm365938_g0_t258.nidq.meta", "anm365938_g0_t259.nidq.meta",
                                                                 "anm365938_g0_t260.nidq.meta", "anm365938_g0_t261.nidq.meta", "anm365938_g0_t262.nidq.meta", "anm365938_g0_t263.nidq.meta", "anm365938_g0_t264.nidq.meta", "anm365938_g0_t265.nidq.meta", "anm365938_g0_t266.nidq.meta", "anm365938_g0_t267.nidq.meta", "anm365938_g0_t268.nidq.meta", "anm365938_g0_t269.nidq.meta",
                                                                 "anm365938_g0_t270.nidq.meta", "anm365938_g0_t271.nidq.meta", "anm365938_g0_t272.nidq.meta", "anm365938_g0_t273.nidq.meta", "anm365938_g0_t274.nidq.meta", "anm365938_g0_t275.nidq.meta", "anm365938_g0_t276.nidq.meta", "anm365938_g0_t277.nidq.meta", "anm365938_g0_t278.nidq.meta", "anm365938_g0_t279.nidq.meta",
                                                                 "anm365938_g0_t280.nidq.meta", "anm365938_g0_t281.nidq.meta", "anm365938_g0_t282.nidq.meta", "anm365938_g0_t283.nidq.meta", "anm365938_g0_t284.nidq.meta", "anm365938_g0_t285.nidq.meta", "anm365938_g0_t286.nidq.meta", "anm365938_g0_t287.nidq.meta", "anm365938_g0_t288.nidq.meta", "anm365938_g0_t289.nidq.meta",
                                                                 "anm365938_g0_t290.nidq.meta", "anm365938_g0_t291.nidq.meta", "anm365938_g0_t292.nidq.meta", "anm365938_g0_t293.nidq.meta", "anm365938_g0_t294.nidq.meta", "anm365938_g0_t295.nidq.meta", "anm365938_g0_t296.nidq.meta", "anm365938_g0_t297.nidq.meta", "anm365938_g0_t298.nidq.meta", "anm365938_g0_t299.nidq.meta",
                                                                 "anm365938_g0_t300.nidq.meta", "anm365938_g0_t301.nidq.meta", "anm365938_g0_t302.nidq.meta", "anm365938_g0_t303.nidq.meta", "anm365938_g0_t304.nidq.meta", "anm365938_g0_t305.nidq.meta", "anm365938_g0_t306.nidq.meta", "anm365938_g0_t307.nidq.meta", "anm365938_g0_t308.nidq.meta", "anm365938_g0_t309.nidq.meta",
                                                                 "anm365938_g0_t310.nidq.meta", "anm365938_g0_t311.nidq.meta", "anm365938_g0_t312.nidq.meta", "anm365938_g0_t313.nidq.meta", "anm365938_g0_t314.nidq.meta", "anm365938_g0_t315.nidq.meta", "anm365938_g0_t316.nidq.meta", "anm365938_g0_t317.nidq.meta", "anm365938_g0_t318.nidq.meta", "anm365938_g0_t319.nidq.meta",
                                                                 "anm365938_g0_t320.nidq.meta", "anm365938_g0_t321.nidq.meta", "anm365938_g0_t322.nidq.meta", "anm365938_g0_t323.nidq.meta", "anm365938_g0_t324.nidq.meta", "anm365938_g0_t325.nidq.meta", "anm365938_g0_t326.nidq.meta", "anm365938_g0_t327.nidq.meta", "anm365938_g0_t328.nidq.meta", "anm365938_g0_t329.nidq.meta",
                                                                 "anm365938_g0_t330.nidq.meta", "anm365938_g0_t331.nidq.meta", "anm365938_g0_t332.nidq.meta", "anm365938_g0_t333.nidq.meta", "anm365938_g0_t334.nidq.meta", "anm365938_g0_t335.nidq.meta", "anm365938_g0_t336.nidq.meta", "anm365938_g0_t337.nidq.meta", "anm365938_g0_t338.nidq.meta", "anm365938_g0_t339.nidq.meta",
                                                                 "anm365938_g0_t340.nidq.meta", "anm365938_g0_t341.nidq.meta", "anm365938_g0_t342.nidq.meta", "anm365938_g0_t343.nidq.meta", "anm365938_g0_t344.nidq.meta", "anm365938_g0_t345.nidq.meta", "anm365938_g0_t346.nidq.meta", "anm365938_g0_t347.nidq.meta", "anm365938_g0_t348.nidq.meta", "anm365938_g0_t349.nidq.meta",
                                                                 "anm365938_g0_t350.nidq.meta", "anm365938_g0_t351.nidq.meta", "anm365938_g0_t352.nidq.meta", "anm365938_g0_t353.nidq.meta", "anm365938_g0_t354.nidq.meta", "anm365938_g0_t355.nidq.meta", "anm365938_g0_t356.nidq.meta", "anm365938_g0_t357.nidq.meta", "anm365938_g0_t358.nidq.meta", "anm365938_g0_t359.nidq.meta",
                                                                 "anm365938_g0_t360.nidq.meta", "anm365938_g0_t361.nidq.meta", "anm365938_g0_t362.nidq.meta", "anm365938_g0_t363.nidq.meta", "anm365938_g0_t364.nidq.meta", "anm365938_g0_t365.nidq.meta", "anm365938_g0_t366.nidq.meta", "anm365938_g0_t367.nidq.meta", "anm365938_g0_t368.nidq.meta", "anm365938_g0_t369.nidq.meta",
                                                                 "anm365938_g0_t370.nidq.meta", "anm365938_g0_t371.nidq.meta", "anm365938_g0_t372.nidq.meta", "anm365938_g0_t373.nidq.meta", "anm365938_g0_t374.nidq.meta", "anm365938_g0_t375.nidq.meta", "anm365938_g0_t376.nidq.meta", "anm365938_g0_t377.nidq.meta", "anm365938_g0_t378.nidq.meta", "anm365938_g0_t379.nidq.meta",
                                                                 "anm365938_g0_t380.nidq.meta", "anm365938_g0_t381.nidq.meta", "anm365938_g0_t382.nidq.meta", "anm365938_g0_t383.nidq.meta", "anm365938_g0_t384.nidq.meta", "anm365938_g0_t385.nidq.meta", "anm365938_g0_t386.nidq.meta", "anm365938_g0_t387.nidq.meta", "anm365938_g0_t388.nidq.meta", "anm365938_g0_t389.nidq.meta",
                                                                 "anm365938_g0_t390.nidq.meta", "anm365938_g0_t391.nidq.meta", "anm365938_g0_t392.nidq.meta", "anm365938_g0_t393.nidq.meta", "anm365938_g0_t394.nidq.meta", "anm365938_g0_t395.nidq.meta", "anm365938_g0_t396.nidq.meta", "anm365938_g0_t397.nidq.meta", "anm365938_g0_t398.nidq.meta", "anm365938_g0_t399.nidq.meta",
                                                                 "anm365938_g0_t400.nidq.meta", "anm365938_g0_t401.nidq.meta", "anm365938_g0_t402.nidq.meta", "anm365938_g0_t403.nidq.meta", "anm365938_g0_t404.nidq.meta", "anm365938_g0_t405.nidq.meta", "anm365938_g0_t406.nidq.meta", "anm365938_g0_t407.nidq.meta", "anm365938_g0_t408.nidq.meta", "anm365938_g0_t409.nidq.meta",
                                                                 "anm365938_g0_t410.nidq.meta", "anm365938_g0_t411.nidq.meta", "anm365938_g0_t412.nidq.meta", "anm365938_g0_t413.nidq.meta", "anm365938_g0_t414.nidq.meta", "anm365938_g0_t415.nidq.meta", "anm365938_g0_t416.nidq.meta", "anm365938_g0_t417.nidq.meta", "anm365938_g0_t418.nidq.meta", "anm365938_g0_t419.nidq.meta",
                                                                 "anm365938_g0_t420.nidq.meta", "anm365938_g0_t421.nidq.meta", "anm365938_g0_t422.nidq.meta", "anm365938_g0_t423.nidq.meta", "anm365938_g0_t424.nidq.meta", "anm365938_g0_t425.nidq.meta", "anm365938_g0_t426.nidq.meta", "anm365938_g0_t427.nidq.meta", "anm365938_g0_t428.nidq.meta", "anm365938_g0_t429.nidq.meta",
                                                                 "anm365938_g0_t430.nidq.meta", "anm365938_g0_t431.nidq.meta", "anm365938_g0_t432.nidq.meta", "anm365938_g0_t433.nidq.meta", "anm365938_g0_t434.nidq.meta", "anm365938_g0_t435.nidq.meta", "anm365938_g0_t436.nidq.meta", "anm365938_g0_t437.nidq.meta", "anm365938_g0_t438.nidq.meta", "anm365938_g0_t439.nidq.meta",
                                                                 "anm365938_g0_t440.nidq.meta", "anm365938_g0_t441.nidq.meta", "anm365938_g0_t442.nidq.meta", "anm365938_g0_t443.nidq.meta", "anm365938_g0_t444.nidq.meta", "anm365938_g0_t445.nidq.meta", "anm365938_g0_t446.nidq.meta", "anm365938_g0_t447.nidq.meta", "anm365938_g0_t448.nidq.meta", "anm365938_g0_t449.nidq.meta",
                                                                 "anm365938_g0_t450.nidq.meta", "anm365938_g0_t451.nidq.meta", "anm365938_g0_t452.nidq.meta", "anm365938_g0_t453.nidq.meta", "anm365938_g0_t454.nidq.meta", "anm365938_g0_t455.nidq.meta", "anm365938_g0_t456.nidq.meta", "anm365938_g0_t457.nidq.meta", "anm365938_g0_t458.nidq.meta", "anm365938_g0_t459.nidq.meta",
                                                                 "anm365938_g0_t460.nidq.meta", "anm365938_g0_t461.nidq.meta", "anm365938_g0_t462.nidq.meta", "anm365938_g0_t463.nidq.meta", "anm365938_g0_t464.nidq.meta", "anm365938_g0_t465.nidq.meta", "anm365938_g0_t466.nidq.meta", "anm365938_g0_t467.nidq.meta", "anm365938_g0_t468.nidq.meta", "anm365938_g0_t469.nidq.meta",
                                                                 "anm365938_g0_t470.nidq.meta", "anm365938_g0_t471.nidq.meta", "anm365938_g0_t472.nidq.meta", "anm365938_g0_t473.nidq.meta", "anm365938_g0_t474.nidq.meta", "anm365938_g0_t475.nidq.meta", "anm365938_g0_t476.nidq.meta", "anm365938_g0_t477.nidq.meta", "anm365938_g0_t478.nidq.meta", "anm365938_g0_t479.nidq.meta",
                                                                 "anm365938_g0_t480.nidq.meta", "anm365938_g0_t481.nidq.meta", "anm365938_g0_t482.nidq.meta", "anm365938_g0_t483.nidq.meta", "anm365938_g0_t484.nidq.meta", "anm365938_g0_t485.nidq.meta", "anm365938_g0_t486.nidq.meta", "anm365938_g0_t487.nidq.meta", "anm365938_g0_t488.nidq.meta", "anm365938_g0_t489.nidq.meta",
                                                                 "anm365938_g0_t490.nidq.meta", "anm365938_g0_t491.nidq.meta", "anm365938_g0_t492.nidq.meta", "anm365938_g0_t493.nidq.meta", "anm365938_g0_t494.nidq.meta", "anm365938_g0_t495.nidq.meta", "anm365938_g0_t496.nidq.meta", "anm365938_g0_t497.nidq.meta", "anm365938_g0_t498.nidq.meta", "anm365938_g0_t499.nidq.meta",
                                                                 "anm365938_g0_t500.nidq.meta", "anm365938_g0_t501.nidq.meta", "anm365938_g0_t502.nidq.meta", "anm365938_g0_t503.nidq.meta", "anm365938_g0_t504.nidq.meta", "anm365938_g0_t505.nidq.meta", "anm365938_g0_t506.nidq.meta", "anm365938_g0_t507.nidq.meta", "anm365938_g0_t508.nidq.meta", "anm365938_g0_t509.nidq.meta",
                                                                 "anm365938_g0_t510.nidq.meta", "anm365938_g0_t511.nidq.meta", "anm365938_g0_t512.nidq.meta", "anm365938_g0_t513.nidq.meta", "anm365938_g0_t514.nidq.meta", "anm365938_g0_t515.nidq.meta", "anm365938_g0_t516.nidq.meta", "anm365938_g0_t517.nidq.meta", "anm365938_g0_t518.nidq.meta", "anm365938_g0_t519.nidq.meta",
                                                                 "anm365938_g0_t520.nidq.meta", "anm365938_g0_t521.nidq.meta", "anm365938_g0_t522.nidq.meta", "anm365938_g0_t523.nidq.meta", "anm365938_g0_t524.nidq.meta", "anm365938_g0_t525.nidq.meta", "anm365938_g0_t526.nidq.meta", "anm365938_g0_t527.nidq.meta", "anm365938_g0_t528.nidq.meta", "anm365938_g0_t529.nidq.meta",
                                                                 "anm365938_g0_t530.nidq.meta", "anm365938_g0_t531.nidq.meta", "anm365938_g0_t532.nidq.meta", "anm365938_g0_t533.nidq.meta", "anm365938_g0_t534.nidq.meta", "anm365938_g0_t535.nidq.meta", "anm365938_g0_t536.nidq.meta", "anm365938_g0_t537.nidq.meta", "anm365938_g0_t538.nidq.meta", "anm365938_g0_t539.nidq.meta"]]

        with open(op.join(testbase, "io", "times.txt"), "r") as fh:
            times = np.array([int(l.strip()) for l in fh.readlines()])
        self.times = np.sort(times - times[0])

    def test_start_times(self):
        assert((spikegl.get_start_times(self.filenames) == self.times).all())

    def test_missing_file(self):
        with pytest.raises(IOError):
            spikegl.get_start_times([op.join(testbase, "io", "not-a-file.meta")])
